@@ -25,7 +25,6 @@ from sushy.resources import constants as res_cons
 from sushy.resources.manager import manager
 from sushy.resources.oem import fake
 from sushy.resources.system import bios
-from sushy.resources.system import mappings as sys_map
 from sushy.resources.system import processor
 from sushy.resources.system import secure_boot
 from sushy.resources.system import simple_storage
@@ -56,23 +55,21 @@ class SystemTestCase(base.TestCase):
         self.assertEqual('Web Front End node', self.sys_inst.description)
         self.assertEqual('web483', self.sys_inst.hostname)
         self.assertEqual('437XR1138R2', self.sys_inst.identity)
-        self.assertEqual(sushy.INDICATOR_LED_OFF,
+        self.assertEqual(sushy.IndicatorLED.OFF,
                          self.sys_inst.indicator_led)
         self.assertEqual('Contoso', self.sys_inst.manufacturer)
         self.assertEqual('WebFrontEnd483', self.sys_inst.name)
         self.assertEqual('224071-J23', self.sys_inst.part_number)
         self.assertEqual('437XR1138R2', self.sys_inst.serial_number)
         self.assertEqual('8675309', self.sys_inst.sku)
-        self.assertEqual(sushy.SYSTEM_TYPE_PHYSICAL,
-                         self.sys_inst.system_type)
+        self.assertEqual(sushy.SystemType.PHYSICAL, self.sys_inst.system_type)
         self.assertEqual('38947555-7742-3448-3784-823347823834',
                          self.sys_inst.uuid)
-        self.assertEqual(res_cons.STATE_ENABLED, self.sys_inst.status.state)
-        self.assertEqual(res_cons.HEALTH_OK, self.sys_inst.status.health)
-        self.assertEqual(res_cons.HEALTH_OK,
+        self.assertEqual(res_cons.State.ENABLED, self.sys_inst.status.state)
+        self.assertEqual(res_cons.Health.OK, self.sys_inst.status.health)
+        self.assertEqual(res_cons.Health.OK,
                          self.sys_inst.status.health_rollup)
-        self.assertEqual(sushy.SYSTEM_POWER_STATE_ON,
-                         self.sys_inst.power_state)
+        self.assertEqual(sushy.PowerState.ON, self.sys_inst.power_state)
         self.assertEqual(96, self.sys_inst.memory_summary.size_gib)
         self.assertEqual("OK", self.sys_inst.memory_summary.health)
         self.assertIsNotNone(self.sys_inst.maintenance_window)
@@ -89,36 +86,37 @@ class SystemTestCase(base.TestCase):
 
         # Test that various types are returned correctly
         self.assertEqual('Chicago-45Z-2381', attributes.get('asset_tag'))
-        self.assertEqual(sushy.INDICATOR_LED_OFF,
+        self.assertEqual(sushy.IndicatorLED.OFF,
                          attributes.get('indicator_led'))
-        self.assertEqual({'health': res_cons.HEALTH_OK,
-                          'health_rollup': res_cons.HEALTH_OK,
-                          'state': res_cons.STATE_ENABLED},
+        self.assertEqual({'health': res_cons.Health.OK,
+                          'health_rollup': res_cons.Health.OK,
+                          'state': res_cons.State.ENABLED},
                          attributes.get('status'))
         self.assertEqual({'maintenance_window_duration_in_seconds': 1,
                           'maintenance_window_start_time':
                           parser.parse('2016-03-07T14:44:30-05:05')},
                          attributes.get('maintenance_window'))
-        self.assertEqual({'reset': {'allowed_values':
-                         ['On', 'ForceOff', 'GracefulShutdown',
-                             'GracefulRestart', 'ForceRestart', 'Nmi',
-                             'ForceOn', 'PushPowerButton'],
-                         'operation_apply_time_support':
-                         {'_maintenance_window_resource':
-                             {'resource_uri':
-                                 '/redfish/v1/Systems/437XR1138R2'},
-                          'maintenance_window_duration_in_seconds': 600,
-                          'maintenance_window_start_time':
-                              parser.parse('2017-05-03T23:12:37-05:00'),
-                          'supported_values':
-                              ['Immediate', 'AtMaintenanceWindowStart'],
-                          'mapped_supported_values':
-                              [res_cons.APPLY_TIME_IMMEDIATE,
-                               res_cons.APPLY_TIME_MAINT_START]},
-                         'target_uri':
-                         '/redfish/v1/Systems/437XR1138R2/Actions/'
-                         'ComputerSystem.Reset'}},
-                         attributes.get('_actions'))
+        self.assertEqual(
+            {'reset': {'allowed_values':
+                       ['On', 'ForceOff', 'GracefulShutdown',
+                        'GracefulRestart', 'ForceRestart', 'Nmi',
+                        'ForceOn', 'PushPowerButton'],
+                       'operation_apply_time_support':
+                       {'_maintenance_window_resource':
+                        {'resource_uri':
+                         '/redfish/v1/Systems/437XR1138R2'},
+                        'maintenance_window_duration_in_seconds': 600,
+                        'maintenance_window_start_time':
+                        parser.parse('2017-05-03T23:12:37-05:00'),
+                        'supported_values':
+                        ['Immediate', 'AtMaintenanceWindowStart'],
+                        'mapped_supported_values':
+                        [res_cons.ApplyTime.IMMEDIATE,
+                         res_cons.ApplyTime.AT_MAINTENANCE_WINDOW_START]},
+                       'target_uri':
+                       '/redfish/v1/Systems/437XR1138R2/Actions/'
+                       'ComputerSystem.Reset'}},
+            attributes.get('_actions'))
 
     def test__parse_attributes_missing_actions(self):
         self.sys_inst.json.pop('Actions')
@@ -177,14 +175,14 @@ class SystemTestCase(base.TestCase):
 
     def test_get_allowed_reset_system_values(self):
         values = self.sys_inst.get_allowed_reset_system_values()
-        expected = set([sushy.RESET_GRACEFUL_SHUTDOWN,
-                        sushy.RESET_GRACEFUL_RESTART,
-                        sushy.RESET_FORCE_RESTART,
-                        sushy.RESET_FORCE_OFF,
-                        sushy.RESET_FORCE_ON,
-                        sushy.RESET_ON,
-                        sushy.RESET_NMI,
-                        sushy.RESET_PUSH_POWER_BUTTON])
+        expected = set([sushy.ResetType.GRACEFUL_SHUTDOWN,
+                        sushy.ResetType.GRACEFUL_RESTART,
+                        sushy.ResetType.FORCE_RESTART,
+                        sushy.ResetType.FORCE_OFF,
+                        sushy.ResetType.FORCE_ON,
+                        sushy.ResetType.ON,
+                        sushy.ResetType.NMI,
+                        sushy.ResetType.PUSH_POWER_BUTTON])
         self.assertEqual(expected, values)
         self.assertIsInstance(values, set)
 
@@ -194,14 +192,18 @@ class SystemTestCase(base.TestCase):
         self.sys_inst._actions.reset.allowed_values = {}
         values = self.sys_inst.get_allowed_reset_system_values()
         # Assert it returns all values if it can't get the specific ones
-        expected = set([sushy.RESET_GRACEFUL_SHUTDOWN,
-                        sushy.RESET_GRACEFUL_RESTART,
-                        sushy.RESET_FORCE_RESTART,
-                        sushy.RESET_FORCE_OFF,
-                        sushy.RESET_FORCE_ON,
-                        sushy.RESET_ON,
-                        sushy.RESET_NMI,
-                        sushy.RESET_PUSH_POWER_BUTTON])
+        expected = set([sushy.ResetType.GRACEFUL_SHUTDOWN,
+                        sushy.ResetType.GRACEFUL_RESTART,
+                        sushy.ResetType.FORCE_RESTART,
+                        sushy.ResetType.FORCE_OFF,
+                        sushy.ResetType.FORCE_ON,
+                        sushy.ResetType.ON,
+                        sushy.ResetType.NMI,
+                        sushy.ResetType.PUSH_POWER_BUTTON,
+                        sushy.ResetType.POWER_CYCLE,
+                        sushy.ResetType.SUSPEND,
+                        sushy.ResetType.RESUME,
+                        sushy.ResetType.PAUSE])
         self.assertEqual(expected, values)
         self.assertIsInstance(values, set)
         self.assertEqual(1, mock_log.call_count)
@@ -211,8 +213,8 @@ class SystemTestCase(base.TestCase):
         self.assertIsNotNone(support)
         self.assertEqual(['Immediate', 'AtMaintenanceWindowStart'],
                          support.supported_values)
-        self.assertEqual([res_cons.APPLY_TIME_IMMEDIATE,
-                          res_cons.APPLY_TIME_MAINT_START],
+        self.assertEqual([res_cons.ApplyTime.IMMEDIATE,
+                          res_cons.ApplyTime.AT_MAINTENANCE_WINDOW_START],
                          support.mapped_supported_values)
         self.assertEqual(parser.parse('2017-05-03T23:12:37-05:00'),
                          support.maintenance_window_start_time)
@@ -221,7 +223,7 @@ class SystemTestCase(base.TestCase):
                          support._maintenance_window_resource.resource_uri)
 
     def test_reset_system(self):
-        self.sys_inst.reset_system(sushy.RESET_FORCE_OFF)
+        self.sys_inst.reset_system(sushy.ResetType.FORCE_OFF)
         self.sys_inst._conn.post.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2/Actions/ComputerSystem.Reset',
             data={'ResetType': 'ForceOff'})
@@ -232,16 +234,16 @@ class SystemTestCase(base.TestCase):
 
     def test_get_allowed_system_boot_source_values(self):
         values = self.sys_inst.get_allowed_system_boot_source_values()
-        expected = set([sushy.BOOT_SOURCE_TARGET_NONE,
-                        sushy.BOOT_SOURCE_TARGET_PXE,
-                        sushy.BOOT_SOURCE_TARGET_CD,
-                        sushy.BOOT_SOURCE_TARGET_USB,
-                        sushy.BOOT_SOURCE_TARGET_HDD,
-                        sushy.BOOT_SOURCE_TARGET_BIOS_SETUP,
-                        sushy.BOOT_SOURCE_TARGET_UTILITIES,
-                        sushy.BOOT_SOURCE_TARGET_DIAGS,
-                        sushy.BOOT_SOURCE_TARGET_SD_CARD,
-                        sushy.BOOT_SOURCE_TARGET_UEFI_TARGET])
+        expected = set([sushy.BootSource.NONE,
+                        sushy.BootSource.PXE,
+                        sushy.BootSource.CD,
+                        sushy.BootSource.USB,
+                        sushy.BootSource.HDD,
+                        sushy.BootSource.BIOS_SETUP,
+                        sushy.BootSource.UTILITIES,
+                        sushy.BootSource.DIAGS,
+                        sushy.BootSource.SD_CARD,
+                        sushy.BootSource.UEFI_TARGET])
         self.assertEqual(expected, values)
         self.assertIsInstance(values, set)
 
@@ -251,71 +253,73 @@ class SystemTestCase(base.TestCase):
         self.sys_inst.boot.allowed_values = None
         values = self.sys_inst.get_allowed_system_boot_source_values()
         # Assert it returns all values if it can't get the specific ones
-        expected = set([sushy.BOOT_SOURCE_TARGET_NONE,
-                        sushy.BOOT_SOURCE_TARGET_PXE,
-                        sushy.BOOT_SOURCE_TARGET_CD,
-                        sushy.BOOT_SOURCE_TARGET_USB,
-                        sushy.BOOT_SOURCE_TARGET_USB_CD,
-                        sushy.BOOT_SOURCE_TARGET_HDD,
-                        sushy.BOOT_SOURCE_TARGET_BIOS_SETUP,
-                        sushy.BOOT_SOURCE_TARGET_UTILITIES,
-                        sushy.BOOT_SOURCE_TARGET_DIAGS,
-                        sushy.BOOT_SOURCE_TARGET_SD_CARD,
-                        sushy.BOOT_SOURCE_TARGET_FLOPPY,
-                        sushy.BOOT_SOURCE_TARGET_UEFI_TARGET,
-                        sushy.BOOT_SOURCE_TARGET_UEFI_SHELL,
-                        sushy.BOOT_SOURCE_TARGET_UEFI_HTTP])
+        expected = set([sushy.BootSource.NONE,
+                        sushy.BootSource.PXE,
+                        sushy.BootSource.CD,
+                        sushy.BootSource.USB,
+                        sushy.BootSource.HDD,
+                        sushy.BootSource.BIOS_SETUP,
+                        sushy.BootSource.UTILITIES,
+                        sushy.BootSource.DIAGS,
+                        sushy.BootSource.SD_CARD,
+                        sushy.BootSource.FLOPPY,
+                        sushy.BootSource.UEFI_TARGET,
+                        sushy.BootSource.UEFI_SHELL,
+                        sushy.BootSource.UEFI_HTTP,
+                        sushy.BootSource.REMOTE_DRIVE,
+                        sushy.BootSource.UEFI_BOOT_NEXT,
+                        sushy.BootSource.USB_CD])
         self.assertEqual(expected, values)
         self.assertIsInstance(values, set)
         self.assertEqual(1, mock_log.call_count)
 
     def test_set_system_boot_options(self):
         self.sys_inst.set_system_boot_options(
-            sushy.BOOT_SOURCE_TARGET_PXE,
-            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
-            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+            sushy.BootSource.PXE,
+            enabled=sushy.BootSourceOverrideEnabled.CONTINUOUS,
+            mode=sushy.BootSourceOverrideMode.UEFI)
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_options_no_mode_specified(self):
         self.sys_inst.set_system_boot_options(
-            sushy.BOOT_SOURCE_TARGET_HDD,
-            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
+            sushy.BootSource.HDD,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE)
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Hdd'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_options_no_target_specified(self):
         self.sys_inst.set_system_boot_options(
-            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
-            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+            enabled=sushy.BootSourceOverrideEnabled.CONTINUOUS,
+            mode=sushy.BootSourceOverrideMode.UEFI)
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideMode': 'UEFI'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_options_no_freq_specified(self):
         self.sys_inst.set_system_boot_options(
-            target=sushy.BOOT_SOURCE_TARGET_PXE,
-            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+            target=sushy.BootSource.PXE,
+            mode=sushy.BootSourceOverrideMode.UEFI)
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_options_nothing_specified(self):
         self.sys_inst.set_system_boot_options()
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2', data={},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_options_invalid_target(self):
         self.assertRaises(exceptions.InvalidParameterValueError,
@@ -326,10 +330,10 @@ class SystemTestCase(base.TestCase):
         with self.assertRaisesRegex(
             exceptions.InvalidParameterValueError,
             '"enabled" value.*{0}'.format(
-                list(sys_map.BOOT_SOURCE_ENABLED_MAP_REV))):
+                list(sushy.BootSourceOverrideEnabled))):
 
             self.sys_inst.set_system_boot_options(
-                sushy.BOOT_SOURCE_TARGET_HDD,
+                sushy.BootSource.HDD,
                 enabled='invalid-enabled')
 
     def test_set_system_boot_options_supermicro_usb_cd_boot(self):
@@ -339,75 +343,39 @@ class SystemTestCase(base.TestCase):
 
         self.sys_inst.manufacturer = "supermicro"
         self.sys_inst.set_system_boot_options(
-            target=sushy.BOOT_SOURCE_TARGET_CD,
-            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
+            target=sushy.BootSource.CD,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE)
 
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'UsbCd'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_options_supermicro_no_usb_cd_boot(self):
 
         self.sys_inst.manufacturer = "supermicro"
         self.sys_inst.set_system_boot_options(
-            target=sushy.BOOT_SOURCE_TARGET_CD,
-            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
+            target=sushy.BootSource.CD,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE)
 
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Cd'}},
-            etag=None)
-
-    def test_set_system_boot_options_settings_resource_nokia(self):
-        self.conn.get.return_value.headers = {'ETag': '"3d7b838291941d"'}
-        with open('sushy/tests/unit/json_samples/settings-nokia.json') as f:
-            settings_obj = json.load(f)
-
-        self.json_doc.update(settings_obj)
-        self.sys_inst._parse_attributes(self.json_doc)
-
-        self.sys_inst.set_system_boot_options(
-            target=sushy.BOOT_SOURCE_TARGET_CD,
-            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
-
-        self.sys_inst._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/Self/SD',
-            data={'Boot': {'BootSourceOverrideEnabled': 'Once',
-                           'BootSourceOverrideTarget': 'Cd'}},
-            etag='"3d7b838291941d"')
-
-    def test_set_system_boot_options_settings_resource(self):
-        self.conn.get.return_value.headers = {'ETag': '"3d7b838291941d"'}
-        with open('sushy/tests/unit/json_samples/settings.json') as f:
-            settings_obj = json.load(f)
-
-        self.json_doc.update(settings_obj)
-        self.sys_inst._parse_attributes(self.json_doc)
-
-        self.sys_inst.set_system_boot_options(
-            target=sushy.BOOT_SOURCE_TARGET_CD,
-            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
-
-        self.sys_inst._conn.patch.assert_called_once_with(
-            '/redfish/v1/Systems/437XR1138R2/BIOS/Settings',
-            data={'Boot': {'BootSourceOverrideEnabled': 'Once',
-                           'BootSourceOverrideTarget': 'Cd'}},
-            etag='"3d7b838291941d"')
+            headers=None)
 
     def test_set_system_boot_source(self):
         self.sys_inst.set_system_boot_source(
-            sushy.BOOT_SOURCE_TARGET_PXE,
-            enabled=sushy.BOOT_SOURCE_ENABLED_CONTINUOUS,
-            mode=sushy.BOOT_SOURCE_MODE_UEFI)
+            sushy.BootSource.PXE,
+            enabled=sushy.BootSourceOverrideEnabled.CONTINUOUS,
+            mode=sushy.BootSourceOverrideMode.UEFI)
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_source_with_etag(self):
         self.conn.get.return_value.headers = {'ETag': '"3d7b838291941d"'}
@@ -420,17 +388,17 @@ class SystemTestCase(base.TestCase):
             data={'Boot': {'BootSourceOverrideEnabled': 'Continuous',
                            'BootSourceOverrideTarget': 'Pxe',
                            'BootSourceOverrideMode': 'UEFI'}},
-            etag='"3d7b838291941d"')
+            headers={'If-Match': '"3d7b838291941d"'})
 
     def test_set_system_boot_source_no_mode_specified(self):
         self.sys_inst.set_system_boot_source(
-            sushy.BOOT_SOURCE_TARGET_HDD,
-            enabled=sushy.BOOT_SOURCE_ENABLED_ONCE)
+            sushy.BootSource.HDD,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE)
         self.sys_inst._conn.patch.assert_called_once_with(
             '/redfish/v1/Systems/437XR1138R2',
             data={'Boot': {'BootSourceOverrideEnabled': 'Once',
                            'BootSourceOverrideTarget': 'Hdd'}},
-            etag=None)
+            headers=None)
 
     def test_set_system_boot_source_invalid_target(self):
         self.assertRaises(exceptions.InvalidParameterValueError,
@@ -441,16 +409,16 @@ class SystemTestCase(base.TestCase):
         with self.assertRaisesRegex(
             exceptions.InvalidParameterValueError,
             '"enabled" value.*{0}'.format(
-                list(sys_map.BOOT_SOURCE_ENABLED_MAP_REV))):
+                list(sushy.BootSourceOverrideEnabled))):
 
             self.sys_inst.set_system_boot_source(
-                sushy.BOOT_SOURCE_TARGET_HDD,
+                sushy.BootSource.HDD,
                 enabled='invalid-enabled')
 
     def test_set_indicator_led(self):
         with mock.patch.object(
                 self.sys_inst, 'invalidate', autospec=True) as invalidate_mock:
-            self.sys_inst.set_indicator_led(sushy.INDICATOR_LED_BLINKING)
+            self.sys_inst.set_indicator_led(sushy.IndicatorLED.BLINKING)
             self.sys_inst._conn.patch.assert_called_once_with(
                 '/redfish/v1/Systems/437XR1138R2',
                 data={'IndicatorLED': 'Blinking'})
@@ -569,10 +537,10 @@ class SystemTestCase(base.TestCase):
         # | WHEN |
         actual_processor_summary = self.sys_inst.processors.summary
         # | THEN |
-        self.assertEqual((16, sushy.PROCESSOR_ARCH_x86),
+        self.assertEqual((16, sushy.ProcessorArchitecture.X86),
                          actual_processor_summary)
         self.assertEqual(16, actual_processor_summary.count)
-        self.assertEqual(sushy.PROCESSOR_ARCH_x86,
+        self.assertEqual(sushy.ProcessorArchitecture.X86,
                          actual_processor_summary.architecture)
 
         # reset mock
@@ -600,7 +568,7 @@ class SystemTestCase(base.TestCase):
 
         actual_macs = self.sys_inst.ethernet_interfaces.summary
         expected_macs = (
-            {'12:44:6A:3B:04:11': res_cons.STATE_ENABLED})
+            {'12:44:6A:3B:04:11': res_cons.State.ENABLED})
         self.assertEqual(expected_macs, actual_macs)
 
     def test_bios(self):
